"use client";

import Image from "next/image";

import { Button } from "@/components/ui/button";
import { ImageBaseUrl } from "@/configs/api";
import { Link, Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useMostSelling } from "@/servers/data/use-most-selling";
import { Loader2 } from "lucide-react";
import { useTranslations } from "next-intl";
import { useEffect, useState } from "react";

interface MostSellingProps {
	locale: Locale;
}

export default function MostSelling({ locale }: MostSellingProps) {
	const isRTL = locale === "ar";
	const pageSize = 5;
	const [page, setPage] = useState(1);
	const [hasMore, setHasMore] = useState(true);
	const [visibleProducts, setVisibleProducts] = useState<any[]>([]);
	const [isLoading, setIsLoading] = useState(false);

	const t = useTranslations();
	const { products, isFetching, isLoading: _isLoading } = useMostSelling();

	useEffect(() => {
		if (products) {
			setHasMore(products.length > pageSize * page);
			setVisibleProducts(products.slice(0, pageSize * page));
		}
	}, [products, page]);

	return (
		<section className="container mx-auto max-w-7xl px-4 py-8 lg:py-12" dir={isRTL ? "rtl" : "ltr"}>

			<h2 className="text-2xl text-gray-900 font-bold mb-4" dir={isRTL ? "rtl" : "ltr"}>{t("Best selling products")}</h2>

			<div
				className={cn(
					"flex flex-col gap-6",
				)}
				dir={isRTL ? "rtl" : "ltr"}
			>
				{
					isFetching || _isLoading ? (
						<div className="flex justify-center">
							<Loader2 className="mx-auto h-4 w-4 animate-spin" />
						</div>
					) : (
						<>
							{Array.from({ length: Math.ceil(visibleProducts.length / 5) }).map((_, sectionIndex) => {
								const startIndex = sectionIndex * 5;
								const sectionProducts = visibleProducts.slice(startIndex, startIndex + 5);
								const firstProduct = sectionProducts[0];
								const remainingProducts = sectionProducts.slice(1);

								return (
									<div key={sectionIndex} className="flex flex-row gap-6">
										<div className="w-full lg:w-[45%]">
											<div className="relative h-[350px] w-full overflow-hidden rounded-lg lg:h-full">
												<Image
													src={ImageBaseUrl + firstProduct?.images?.[0]?.image_path}
													alt={firstProduct?.images?.[0]?.name}
													fill
													className="object-cover"
													priority
												/>
												<div className="absolute inset-0 bg-gradient-to-t from-black/60 to-transparent" />
												<div className="absolute bottom-0 left-0 right-0 p-6">
													<h3 className="text-xl font-medium text-white mb-4">
														{locale === "ar" ? firstProduct.name_ar : firstProduct.name_en}
													</h3>
													<Button
														variant="secondary"
														className="rounded-lg border-[#2895C8] text-[#2895C8] hover:bg-white/10"
													>
														<Link href={`products/${firstProduct?.product_slug}` as any}>
															{t("Details")}
														</Link>
													</Button>
												</div>
											</div>
										</div>

										<div className="w-full lg:w-[55%]">
											<div className="grid grid-cols-1 gap-4 sm:grid-cols-2">
												{remainingProducts?.map((_prod: any) => (
													<div
														key={_prod.id}
														className="flex flex-row items-center gap-4 rounded-lg border p-4"
													>
														<div className="relative h-[118px] w-[118px] flex-shrink-0 overflow-hidden rounded-lg">
															<Image
																src={ImageBaseUrl + _prod?.images?.[0]?.image_path}
																alt={_prod?.images?.[0]?.name}
																fill
																className="object-cover"
															/>
														</div>
														<div className="flex flex-col items-center gap-2 text-center sm:items-start sm:text-start">
															<h3 className="text-lg font-medium text-gray-900">
																{locale === "ar" ? _prod.name_ar : _prod.name_en}
															</h3>
															<Button
																variant="secondary"
																className="mt-2 rounded-lg border-[#2895C8] text-[#2895C8] hover:bg-[#2895C8]/5"
															>
																<Link href={`products/${_prod?.product_slug}` as any}>
																	{t("Details")}
																</Link>
															</Button>
														</div>
													</div>
												))}
											</div>
										</div>
									</div>
								);
							})}

							{hasMore && visibleProducts?.length > 0 && (
								<div className="flex justify-center mt-8">
									<Button variant="default" className="w-fit rounded-lg bg-custom-primary-accent text-white hover:bg-custom-primary-accent/90"
										onClick={() => {
											setIsLoading(true);
											setTimeout(() => {
												setPage(page + 1);
												setIsLoading(false);
											}, 3000);
										}}
										disabled={isLoading}
									>
										{isLoading && <Loader2 className="mr-2 h-4 w-4 animate-spin" />}
										{t("Load More")}
									</Button>
								</div>
							)}
						</>
					)
				}
			</div>
		</section>
	);
}

